@@ -1,22 +1,23 @@
-# Allelic frequency histogram for an ecogen genetic data frame
-# Leandro Roser leandroroser@ege.fcen.uba.ar
-# February 18, 2015 
+# Allelic frequency histograms for an ecogen genetic data frame
 
-setGeneric("eco.alfreq", function(eco, fact = NULL) {
+# Leandro Roser leandroroser@ege.fcen.uba.ar
+# May 11, 2015 
+
+setGeneric("eco.alfreq", function(eco, grp = NULL) {
   
-  if(!is.null(fact)) {
-    cual <- which(colnames(eco$S) == fact)
-    fact.num <- as.numeric(levels(eco$S[,cual]))[eco$S[,cual]] 
-    nfact <- max(fact.num)
+  if(!is.null(grp)) {
+    cual <- which(colnames(eco$S) == grp)
+    grp.num <- as.numeric(levels(eco$S[,cual]))[eco$S[,cual]] 
+    nfact <- max(grp.num)
   } else {
     eco$S$dummy <- rep(1, nrow(eco$G))
     cual <- which(colnames(eco$S) =="dummy")
-    fact.num <- as.numeric(levels(as.factor(eco$S[,cual])))[eco$S[,cual]] 
+    grp.num <- as.numeric(levels(as.factor(eco$S[,cual])))[eco$S[,cual]] 
     nfact <- 1
   }
   
+  out <- list()
   for(i in 1:nfact) {
-    
     eco2 <- eco[which(eco$S[,cual] == i)]
     clases<- as.numeric(eco2$GENIND$loc.fac)
     tabla <- eco2@GENIND$tab
@@ -43,9 +44,9 @@ setGeneric("eco.alfreq", function(eco, fact = NULL) {
       ggplot2::geom_histogram(ggplot2::aes(y = ..density..)) + 
       ggplot2::geom_density(alpha = 0.5, fill = "red") +
       ggplot2::labs(title = tit) +
-      ggplot2::xlab("Frequency") +
+      ggplot2::xlab("Frequency class") +
       ggplot2::ylab("Density")
-    suppressMessages(print(grafico))
+    out[[i]] <- grafico
   }
-  
+  out
 })
