@@ -1,6 +1,8 @@
-# Creating an updated ecogen object by adding results to the slot OUT
+# Creating an updated ecogen object by adding 
+# results to the slot @OUT
+
 # Leandro Roser leandroroser@ege.fcen.uba.ar
-# February 18, 2015
+# May 11, 2015
 
 setGeneric("eco.append", function(eco, ...) {
   
@@ -9,6 +11,9 @@ setGeneric("eco.append", function(eco, ...) {
   res.names <- (as.character(match.call()))
   res.names <- res.names[-c(1:2)]
   
+  if(class(eco) != "ecogen") {
+    stop("eco is not an ecogen object")
+  }
   Z <- eco
   nob <- length(Z$OUT)
   nad <-  (nob+1):(nob + length(res))
